@@ -189,7 +189,7 @@ class BaseExperiment:
         if n_classes is None and self.stratify:
             logger.info(f"Cannot perform label stratification in regression tasks. Setting stratify to False.")
             self.stratify = False
-        self.path = str(path).replace(".",str(os.getcwd))
+        self.path = str(path).replace(".",str(os.getcwd()))
         if self.path[-1] == "/":
             self.path = self.path[:-1]
         
